/**********
 * Copyright (c) 2003-2004 Greg Parker.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY GREG PARKER ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **********/

#include "includes.h"
#include "formutils.h"
#include "forms/CollapseUtils.h"
#include "data/hostkeys.h"
#include "rsrc/rsrc.h"

#include "hostkeysform.h"


static Boolean HostKeysFormResize(FormPtr frmP) FORMS_SEGMENT;


Boolean HostKeysFormHandleEvent(EventPtr e)
{
    FormPtr frmP = FrmGetActiveForm();

    switch (e->eType) {
    case frmOpenEvent:
        CollapseSetState(frmP, collapseStateUser);
        HostKeysFormResize(frmP);
        HostKeysUpdate();
        FrmDrawForm(frmP);
        return true;

    case winDisplayChangedEvent:
        PrvHandleDisplayChange(frmP, HostKeysFormResize(frmP));
        return false;

    case winEnterEvent:
        if ((FormPtr)e->data.winEnter.enterWindow == 
            FrmGetFormPtr(HostKeysFormID))
        {
            HostKeysUpdate();
        }
        return false;

    case ctlSelectEvent:
        switch (e->data.ctlSelect.controlID) {

        case HostKeysFormOKButtonID:
            FrmReturnToForm(0);
            break;

        case HostKeysFormDetailsButtonID:
            if (HostKeysSelectedIndex() != noRecord) {
                FrmPopupForm(HostKeyDetailsFormID);
            }
            break;

        default: 
            break;

        }
        return false;

    case frmCloseEvent:
        return false;

    default: 
        HostKeysHandleEvent(e);
        return false;
    }
}


static Boolean HostKeysFormResize(FormPtr frmP)
{
    Int16 dh, dv;
    Boolean changed = CollapseResizeForm(frmP, false, &dh, &dv);
    
    if (!changed) return false;

    // connection table: resize to width and height
    // connection scrollbar: resize to width and height
    // everything else: move vertically

    CollapseMoveResizeFormObject(frmP, HostKeysFormOKButtonID, dh, dv, 0, 0);
    CollapseMoveResizeFormObject(frmP, HostKeysFormDetailsButtonID, dh, dv, 0, 0);

    PrvResizeTableAndScrollbar(frmP, dh, dv, 
                               FrmGetObjectIndex(frmP, HostKeysFormKeyTableID),
                               FrmGetObjectIndex(frmP, HostKeysFormKeyScrollbarID));

    HostKeysUpdate();
    return true;
}
